#ifndef NASM_WARNINGS_H
#define NASM_WARNINGS_H

#ifndef WARN_SHR
# error "warnings.h should only be included from within error.h"
#endif

enum warn_index {
	WARN_IDX_NONE                    =   0, /* not suppressible */
	WARN_IDX_BND                     =   1, /* invalid BND prefixes */
	WARN_IDX_FLOAT_DENORM            =   2, /* floating point denormal */
	WARN_IDX_FLOAT_OVERFLOW          =   3, /* floating point overflow */
	WARN_IDX_FLOAT_TOOLONG           =   4, /* too many digits in floating-point number */
	WARN_IDX_FLOAT_UNDERFLOW         =   5, /* floating point underflow */
	WARN_IDX_HLE                     =   6, /* invalid HLE prefixes */
	WARN_IDX_LABEL_ORPHAN            =   7, /* labels alone on lines without trailing `:' */
	WARN_IDX_LABEL_REDEF             =   8, /* label redefined to an identical value */
	WARN_IDX_LABEL_REDEF_LATE        =   9, /* label (re)defined during code generation */
	WARN_IDX_LOCK                    =  10, /* LOCK prefix on unlockable instructions */
	WARN_IDX_MACRO_DEFAULTS          =  11, /* macros with more default than optional parameters */
	WARN_IDX_MACRO_PARAMS            =  12, /* macro calls with wrong parameter count */
	WARN_IDX_NEGATIVE_REP            =  13, /* regative %rep count */
	WARN_IDX_NUMBER_OVERFLOW         =  14, /* numeric constant does not fit */
	WARN_IDX_OBSOLETE                =  15, /* instruction obsolete for the target CPU */
	WARN_IDX_PHASE                   =  16, /* phase error during stabilization */
	WARN_IDX_PRAGMA_BAD              =  17, /* empty or malformed %pragma */
	WARN_IDX_PRAGMA_NA               =  18, /* %pragma not applicable to this compilation */
	WARN_IDX_PRAGMA_UNKNOWN          =  19, /* unknown %pragma facility or directive */
	WARN_IDX_PTR                     =  20, /* non-NASM keyword used in other assemblers */
	WARN_IDX_UNKNOWN_WARNING         =  21, /* unknown warning in -W/-w or warning directive */
	WARN_IDX_USER                    =  22, /* %warning directives */
	WARN_IDX_WARN_STACK_EMPTY        =  23, /* warning stack empty */
	WARN_IDX_ZEROING                 =  24, /* RESx in initialized section becomes zero */
	WARN_IDX_ZEXT_RELOC              =  25, /* relocation zero-extended to match output format */
	WARN_IDX_OTHER                   =  26, /* any warning not specifially mentioned above */
	WARN_IDX_ALL                     =  27  /* all possible warnings */
};

enum warn_const {
	WARN_NONE                        =   0 << WARN_SHR,
	WARN_BND                         =   1 << WARN_SHR,
	WARN_FLOAT_DENORM                =   2 << WARN_SHR,
	WARN_FLOAT_OVERFLOW              =   3 << WARN_SHR,
	WARN_FLOAT_TOOLONG               =   4 << WARN_SHR,
	WARN_FLOAT_UNDERFLOW             =   5 << WARN_SHR,
	WARN_HLE                         =   6 << WARN_SHR,
	WARN_LABEL_ORPHAN                =   7 << WARN_SHR,
	WARN_LABEL_REDEF                 =   8 << WARN_SHR,
	WARN_LABEL_REDEF_LATE            =   9 << WARN_SHR,
	WARN_LOCK                        =  10 << WARN_SHR,
	WARN_MACRO_DEFAULTS              =  11 << WARN_SHR,
	WARN_MACRO_PARAMS                =  12 << WARN_SHR,
	WARN_NEGATIVE_REP                =  13 << WARN_SHR,
	WARN_NUMBER_OVERFLOW             =  14 << WARN_SHR,
	WARN_OBSOLETE                    =  15 << WARN_SHR,
	WARN_PHASE                       =  16 << WARN_SHR,
	WARN_PRAGMA_BAD                  =  17 << WARN_SHR,
	WARN_PRAGMA_NA                   =  18 << WARN_SHR,
	WARN_PRAGMA_UNKNOWN              =  19 << WARN_SHR,
	WARN_PTR                         =  20 << WARN_SHR,
	WARN_UNKNOWN_WARNING             =  21 << WARN_SHR,
	WARN_USER                        =  22 << WARN_SHR,
	WARN_WARN_STACK_EMPTY            =  23 << WARN_SHR,
	WARN_ZEROING                     =  24 << WARN_SHR,
	WARN_ZEXT_RELOC                  =  25 << WARN_SHR,
	WARN_OTHER                       =  26 << WARN_SHR
};

struct warning_alias {
	const char *name;
	enum warn_index warning;
};

#define NUM_WARNING_ALIAS 31
extern const char * const warning_name[28];
extern const char * const warning_help[28];
extern const struct warning_alias warning_alias[NUM_WARNING_ALIAS];
extern const uint8_t warning_default[27];
extern uint8_t warning_state[27];

#endif /* NASM_WARNINGS_H */
